EventEmitter class

Constructors

EventEmitter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
listeners → List<EventListener<Event>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(EventListener<Event> listener) → void
dispatch(Event event) → bool
emit<T>(String type, [T? data]) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off<T extends Event>({String? type, EventCallback<T>? callback}) → bool
on<T>(String? type, [EventCallback<T>? callback]) → EventListener<Event<T>>
once<T>(String? type, [EventCallback<T>? callback]) → EventListener<Event<T>>
onDispatch<T>([EventCallback<T>? callback]) → EventListener<Event<T>>
removeEventListener(EventListener<Event> listener) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited