EventTarget<T extends Event> mixin

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
nested → bool
no setter
once → bool
no setter
protected → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
no setter

Methods

accepts(Event event) → bool
matches<S extends Event>({String? type, EventCallback<S>? callback, bool? protected, bool? once}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited